@@ -55,6 +55,8 @@ def create_context(is_os_admin=False):
     session = (mock.sentinel.admin_session
                if is_os_admin else
                mock.sentinel.session)
+    session.get_endpoint = mock.Mock(name="get_endpoint")
+    session.get_endpoint.return_value = 'v1'
     return ec2api.context.RequestContext(fakes.ID_OS_USER, fakes.ID_OS_PROJECT,
                                          is_os_admin=is_os_admin,
                                          session=session)
