@@ -222,16 +222,14 @@ class EC2TimestampValidationTestCase(testtools.TestCase):
 
         # EC2 request with Timestamp in advanced time
         timestamp = timeutils.utcnow() + datetime.timedelta(seconds=250)
-        params = {'Timestamp': timeutils.strtime(timestamp,
-                                                 "%Y-%m-%dT%H:%M:%SZ")}
+        params = {'Timestamp': timestamp.strftime("%Y-%m-%dT%H:%M:%SZ")}
         expired = ec2utils.is_ec2_timestamp_expired(params, expires=300)
         self.assertFalse(expired)
 
     @tools.screen_all_logs
     def test_validate_ec2_timestamp_advanced_time_expired(self):
         timestamp = timeutils.utcnow() + datetime.timedelta(seconds=350)
-        params = {'Timestamp': timeutils.strtime(timestamp,
-                                                 "%Y-%m-%dT%H:%M:%SZ")}
+        params = {'Timestamp': timestamp.strftime("%Y-%m-%dT%H:%M:%SZ")}
         expired = ec2utils.is_ec2_timestamp_expired(params, expires=300)
         self.assertTrue(expired)
 
@@ -254,7 +252,7 @@ class EC2TimestampValidationTestCase(testtools.TestCase):
 
     def test_validate_ec2_req_not_expired(self):
         expire = timeutils.utcnow() + datetime.timedelta(seconds=350)
-        params = {'Expires': timeutils.strtime(expire, "%Y-%m-%dT%H:%M:%SZ")}
+        params = {'Expires': expire.strftime("%Y-%m-%dT%H:%M:%SZ")}
         expired = ec2utils.is_ec2_timestamp_expired(params)
         self.assertFalse(expired)
 
